@@ -1,5 +1,5 @@
 from .rustplus_pb2 import *
-from .rustws import RustWsClient
+from .rustws import RustWebsocket
 from .token_bucket import RateLimiter
 from .rust_remote_interface import RustRemote
 from .heartbeat import HeartBeat
