@@ -15,7 +15,7 @@ class RustWebsocket(websocket.WebSocket):
 
         self.ip = ip
         self.port = port
-        self.thread = None
+        self.thread: Thread = None
         self.open = False
         self.use_proxy = use_proxy
         self.remote = remote
@@ -84,6 +84,9 @@ class RustWebsocket(websocket.WebSocket):
         while self.open:
             try:
                 data = self.recv()
+
+                self.remote.event_handler.run_proto_event(data)
+
                 app_message = AppMessage()
                 app_message.ParseFromString(data)
 
@@ -93,7 +96,7 @@ class RustWebsocket(websocket.WebSocket):
                         f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} [RustPlus.py] Connection interrupted, Retrying"
                     )
                     self.connect(ignore=True)
-                    return
+                    continue
                 return
 
             try:
