@@ -8,6 +8,7 @@ class RustInfo:
         self._max_players: int = data.maxPlayers
         self._queued_players: int = data.queuedPlayers
         self._seed: int = data.seed
+        self._wipe_time: int = data.wipeTime
 
     @property
     def url(self) -> str:
@@ -41,14 +42,20 @@ class RustInfo:
     def seed(self) -> int:
         return self._seed
 
+    @property
+    def wipe_time(self) -> int:
+        return self._wipe_time
+
     def __str__(self) -> str:
-        return "RustInfo[url={}, name={}, map={}, size={}, players={}, max_players={}, queued_players={}, seed={}]".format(
-            self._url,
-            self._name,
-            self._map,
-            self._size,
-            self._players,
-            self._max_players,
-            self._queued_players,
-            self._seed,
-        )
+        return "RustInfo[url={}, name={}, map={}, size={}, players={}, max_players={}, queued_players={}, seed={}, " \
+               "wipe_time{}]".format(
+                    self._url,
+                    self._name,
+                    self._map,
+                    self._size,
+                    self._players,
+                    self._max_players,
+                    self._queued_players,
+                    self._seed,
+                    self._wipe_time
+                )
